import { Image as ReactNativeImage } from 'react-native';
import { UrlUtils } from './Url';
export var ImageType;
(function (ImageType) {
    ImageType[ImageType["Remote"] = 0] = "Remote";
    ImageType[ImageType["Local"] = 1] = "Local";
    ImageType[ImageType["Base64"] = 2] = "Base64";
    ImageType[ImageType["Svg"] = 3] = "Svg";
    ImageType[ImageType["Unknown"] = 4] = "Unknown";
})(ImageType || (ImageType = {}));
export class ImageUtils {
    static getSize(uri, success, failure) {
        if (uri) {
            if (UrlUtils.isSvg(uri)) {
                if (success) {
                    success(Number.POSITIVE_INFINITY, Number.POSITIVE_INFINITY);
                }
            }
            else {
                ReactNativeImage.getSize(uri, (width, height) => {
                    if (success) {
                        success(width, height);
                    }
                }, (error) => {
                    if (failure) {
                        failure(error);
                    }
                });
            }
        }
    }
    static prefetch(url) {
        if (UrlUtils.isRemoteUrl(url)) {
            return ReactNativeImage.prefetch(url);
        }
    }
    static abortPrefetch(requestId) {
        ReactNativeImage.abortPrefetch(requestId);
    }
    static queryCache(urls) {
        return ReactNativeImage.queryCache(urls);
    }
    static resolveAssetSource(source) {
        return ReactNativeImage.resolveAssetSource(source);
    }
    static detectType(url) {
        if (url) {
            if (UrlUtils.isEncodedData(url)) {
                if (UrlUtils.isSvg(url)) {
                    return ImageType.Svg;
                }
                return ImageType.Base64;
            }
            else {
                if (UrlUtils.isRemoteUrl(url)) {
                    return ImageType.Remote;
                }
                return ImageType.Local;
            }
        }
        return ImageType.Unknown;
    }
}
